==> graphql-web-lite-16.6.0-2.tgz: package/validation/rules/ValuesOfCorrectTypeRule.js <==
var jsutils_didYouMean = require("../../jsutils/didYouMean.js");

var jsutils_inspect = require("../../jsutils/inspect.js");

var jsutils_keyMap = require("../../jsutils/keyMap.js");

var jsutils_suggestionList = require("../../jsutils/suggestionList.js");

var type_definition = require("../../type/definition.js");

var shared = require("../../shared.js");

function isValidValueNode(context, node) {
  const locationType = context.getInputType();
  if (!locationType) {
    return;
  }
  const type = type_definition.getNamedType(locationType);
  if (!type_definition.isLeafType(type)) {
    const typeStr = jsutils_inspect.inspect(locationType);
    context.reportError(new shared.GraphQLError(`Expected value of type "${typeStr}", found ${shared.print(node)}.`, {
      nodes: node
    }));
    return;
  }
  try {
    if (void 0 === type.parseLiteral(node, void 0)) {
      const typeStr = jsutils_inspect.inspect(locationType);
      context.reportError(new shared.GraphQLError(`Expected value of type "${typeStr}", found ${shared.print(node)}.`, {
        nodes: node
      }));
    }
  } catch (error) {
    const typeStr = jsutils_inspect.inspect(locationType);
    if (error instanceof shared.GraphQLError) {
      context.reportError(error);
    } else {
      context.reportError(new shared.GraphQLError(`Expected value of type "${typeStr}", found ${shared.print(node)}; ` + error.message, {
        nodes: node,
        originalError: error
      }));
    }
  }
}

exports.ValuesOfCorrectTypeRule = function ValuesOfCorrectTypeRule(context) {
  return {
    ListValue(node) {
      const type = type_definition.getNullableType(context.getParentInputType());
      if (!type_definition.isListType(type)) {
        isValidValueNode(context, node);
        return !1;
      }
    },
    ObjectValue(node) {
      const type = type_definition.getNamedType(context.getInputType());
      if (!type_definition.isInputObjectType(type)) {
        isValidValueNode(context, node);
        return !1;
      }
      const fieldNodeMap = jsutils_keyMap.keyMap(node.fields, (field => field.name.value));
      for (const fieldDef of Object.values(type.getFields())) {
        if (!fieldNodeMap[fieldDef.name] && type_definition.isRequiredInputField(fieldDef)) {
          const typeStr = jsutils_inspect.inspect(fieldDef.type);
          context.reportError(new shared.GraphQLError(`Field "${type.name}.${fieldDef.name}" of required type "${typeStr}" was not provided.`, {
            nodes: node
          }));
        }
      }
    },
    ObjectField(node) {
      const parentType = type_definition.getNamedType(context.getParentInputType());
      if (!context.getInputType() && type_definition.isInputObjectType(parentType)) {
        const suggestions = jsutils_suggestionList.suggestionList(node.name.value, Object.keys(parentType.getFields()));
        context.reportError(new shared.GraphQLError(`Field "${node.name.value}" is not defined by type "${parentType.name}".` + jsutils_didYouMean.didYouMean(suggestions), {
          nodes: node
        }));
      }
    },
    NullValue(node) {
      const type = context.getInputType();
      if (type_definition.isNonNullType(type)) {
        context.reportError(new shared.GraphQLError(`Expected value of type "${jsutils_inspect.inspect(type)}", found ${shared.print(node)}.`, {
          nodes: node
        }));
      }
    },
    EnumValue: node => isValidValueNode(context, node),
    IntValue: node => isValidValueNode(context, node),
    FloatValue: node => isValidValueNode(context, node),
    StringValue: node => isValidValueNode(context, node),
    BooleanValue: node => isValidValueNode(context, node)
  };
};

==> graphql-web-lite-16.6.0-4.tgz: package/validation/rules/ValuesOfCorrectTypeRule.js <==
var jsutils_didYouMean = require("../../jsutils/didYouMean.js");

var jsutils_inspect = require("../../jsutils/inspect.js");

var jsutils_keyMap = require("../../jsutils/keyMap.js");

var jsutils_suggestionList = require("../../jsutils/suggestionList.js");

var type_definition = require("../../type/definition.js");

var graphql_web = require("@0no-co/graphql.web");

function isValidValueNode(context, node) {
  const locationType = context.getInputType();
  if (!locationType) {
    return;
  }
  const type = type_definition.getNamedType(locationType);
  if (!type_definition.isLeafType(type)) {
    const typeStr = jsutils_inspect.inspect(locationType);
    context.reportError(new graphql_web.GraphQLError(`Expected value of type "${typeStr}", found ${graphql_web.print(node)}.`, {
      nodes: node
    }));
    return;
  }
  try {
    if (void 0 === type.parseLiteral(node, void 0)) {
      const typeStr = jsutils_inspect.inspect(locationType);
      context.reportError(new graphql_web.GraphQLError(`Expected value of type "${typeStr}", found ${graphql_web.print(node)}.`, {
        nodes: node
      }));
    }
  } catch (error) {
    const typeStr = jsutils_inspect.inspect(locationType);
    if (error instanceof graphql_web.GraphQLError) {
      context.reportError(error);
    } else {
      context.reportError(new graphql_web.GraphQLError(`Expected value of type "${typeStr}", found ${graphql_web.print(node)}; ` + error.message, {
        nodes: node,
        originalError: error
      }));
    }
  }
}

exports.ValuesOfCorrectTypeRule = function ValuesOfCorrectTypeRule(context) {
  return {
    ListValue(node) {
      const type = type_definition.getNullableType(context.getParentInputType());
      if (!type_definition.isListType(type)) {
        isValidValueNode(context, node);
        return !1;
      }
    },
    ObjectValue(node) {
      const type = type_definition.getNamedType(context.getInputType());
      if (!type_definition.isInputObjectType(type)) {
        isValidValueNode(context, node);
        return !1;
      }
      const fieldNodeMap = jsutils_keyMap.keyMap(node.fields, (field => field.name.value));
      for (const fieldDef of Object.values(type.getFields())) {
        if (!fieldNodeMap[fieldDef.name] && type_definition.isRequiredInputField(fieldDef)) {
          const typeStr = jsutils_inspect.inspect(fieldDef.type);
          context.reportError(new graphql_web.GraphQLError(`Field "${type.name}.${fieldDef.name}" of required type "${typeStr}" was not provided.`, {
            nodes: node
          }));
        }
      }
    },
    ObjectField(node) {
      const parentType = type_definition.getNamedType(context.getParentInputType());
      if (!context.getInputType() && type_definition.isInputObjectType(parentType)) {
        const suggestions = jsutils_suggestionList.suggestionList(node.name.value, Object.keys(parentType.getFields()));
        context.reportError(new graphql_web.GraphQLError(`Field "${node.name.value}" is not defined by type "${parentType.name}".` + jsutils_didYouMean.didYouMean(suggestions), {
          nodes: node
        }));
      }
    },
    NullValue(node) {
      const type = context.getInputType();
      if (type_definition.isNonNullType(type)) {
        context.reportError(new graphql_web.GraphQLError(`Expected value of type "${jsutils_inspect.inspect(type)}", found ${graphql_web.print(node)}.`, {
          nodes: node
        }));
      }
    },
    EnumValue: node => isValidValueNode(context, node),
    IntValue: node => isValidValueNode(context, node),
    FloatValue: node => isValidValueNode(context, node),
    StringValue: node => isValidValueNode(context, node),
    BooleanValue: node => isValidValueNode(context, node)
  };
};
